#
# spec file for package python-h5py
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-h5py
Version:        2.10.0
Release:        lp152.2.1
Summary:        Python interface to the Hierarchical Data Format library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/h5py/h5py
Source:         https://files.pythonhosted.org/packages/source/h/h5py/h5py-%{version}.tar.gz
#PATCH-FIX-OPENSUSE no_include_opt.patch -- Don't include /opt/ directory.
Patch0:         no_include_opt.patch
#PATCH-FIX-OPENSUSE remove_unittest2.patch mcepl@suse.cz -- remove dependency unittest2
Patch1:         remove_unittest2.patch
BuildRequires:  %{python_module Cython >= 0.23}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.7}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  hdf5-devel
BuildRequires:  python-rpm-macros
Requires:       hdf5
Requires:       python-numpy >= 1.7
Requires:       python-six
%requires_eq    libhdf5_hl100
%python_subpackages

%description
H5py provides a simple, robust read/write interface to HDF5 data from Python.
Existing Python and Numpy concepts are used for the interface; for example,
datasets on disk are represented by a proxy class that supports slicing, and
has dtype and shape attributes. HDF5 groups are presented using a dictionary
metaphor, indexed by name.

%prep
%setup -q -n h5py-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export PYTHONDONTWRITEBYTECODE=1
# test_float_round_tripping -- overflows on 32bit
# py3 only code must be skipped
%pytest_arch %{buildroot}%{$python_sitearch}/h5py/tests/ -k 'not (test_highlevel_access or test_deprecation_available_ftypes or test_read_uncompressed_offsets or test_read_write_chunk or test_float_round_tripping)'

%files %{python_files}
%license lzf/LICENSE.txt
%doc ANN.rst README.rst lzf/README.txt examples licenses/*
%{python_sitearch}/h5py/
%{python_sitearch}/h5py-%{version}-py*.egg-info

%changelog
* Mon May 11 2020 Dirk Mueller <dmueller@suse.com>
- ensure rebuild when hdf5 version changes (bsc#1150049)
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.10.0:
  * no upstream changelog provided
- Update patch remove_unittest2.patch
- Remove upstream merged fix_failing_x86_test.patch
* Wed Jul 31 2019 Todd R <toddrme2178@gmail.com>
- Add fix_failing_x86_test.patch
  Fixes spurious test failure on x86 platfomrs
  See  gh#h5py/h5py#1163
  From gh#h5py/h5py#1235
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Yodate to 2.9.0:
  Changes from 2.8.0 are too numerous to list here, complete changelog
  is available online at https://github.com/h5py/h5py/releases
- Drop merged patch adjust_mapping_hdf5_error_codes.patch
- Refresh remove_unittest2.patch
* Tue Dec  4 2018 Todd R <toddrme2178@gmail.com>
- Use more reliable test invocation
* Fri Oct 12 2018 Matej Cepl <mcepl@suse.com>
- Remove valuerror-typerror-failing-tests.patch and replace it with
  proper patch (https://github.com/tacaswell/h5py/commit/6653c65e8c8d0.patch)
  in adjust_mapping_hdf5_error_codes.patch.
* Thu Oct 11 2018 Todd R <toddrme2178@gmail.com>
- Fix ldconfig syntax errors.
* Wed Oct 10 2018 Matěj Cepl <mcepl@suse.com>
- Add valuerror-typerror-failing-tests.patch to make two tests pass.
* Mon Aug 13 2018 mcepl@suse.com
- Updated to 2.8.0
  Changes from 2.7.1 are too numerous to list here, complete changelog
  is available online at https://github.com/h5py/h5py/releases
  Patch dont_reorder_compund.patch has been included upstream
- Remove dependency on unittest2
  Patch remove_unittest2.patch facilitates the change
* Thu Jan 25 2018 toddrme2178@gmail.com
- Add dont_reorder_compund.patch
  Fixes builds with numpy 1.14. See:
  https://github.com/h5py/h5py/issues/969
  https://github.com/h5py/h5py/pull/970
* Sun Nov 12 2017 arun@gmx.de
- update patch
- update to version 2.7.1:
  * Bug fixes
    + :issue:`903` Fixed critical issue with cyclic gc which resulted
    in segfaults
    + :issue:`904` Avoid unaligned access fixing h5py on sparc64
    + :issue:`883` Fixed compilation issues for some library locations
    + :issue:`868` Fix deadlock between phil and the import lock in
    py2
    + :issue:`841` Improve windows handling if filenames
    + :issue:`874` Allow close to be called on file multiple times
    + :issue:`867`, :issue:`872` Warn on loaded vs complied hdf5
    version issues
    + :issue:`902` Fix overflow computing size of dataset on windows
    + :issue:`912` Do not mangle capitalization of filenames in error
    messages
    + :issue:`842` Fix longdouble on ppc64le
    + :issue:`862`, :issue:`916` Fix compounds structs with
    variable-size members
* Thu May 11 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to version 0.2.7
  * Python 3.2 is no longer supported
  * Improved testing support
  * Improved python compatibility
  * Documentation improvements
  * setup.py improvements
  * Support for additional HDF5 features added
  * Improvements to type system
- Update to version 0.2.6
  * Support for HDF5 Virtual Dataset API
  * Add MPI Collective I/O Support
  * Numerous build/testing/CI improvements
  * Cleanup of codebase based on pylint
  * Fixes to low-level API
  * Documentation improvements
- Add no_include_opt.patch to avoid including forbidden
  directories.
* Tue Jul 28 2015 toddrme2178@gmail.com
- Fix hdf5 version ambiguity
* Fri Apr 10 2015 toddrme2178@gmail.com
- specfile:
  * changed from 2to3 to six
  * added build requirement for python3-pkgconfig
  * added Cython requirement for install
  * update copyright year
- update to version 2.5.0:
  * Experimental SWMR support
  * Group and AttributeManager classes now inherit from the appropriate ABCs
  * Fixed an issue with 64-bit float VLENS
  * Cython warning cleanups related to "const"
  * Entire code base ported to "six"; 2to3 removed from setup.py
- update to version 2.4.0:
  * This release incorporates a total re-write of the identifier
    management system in h5py. As part of this refactoring, the entire
    API is also now protected by threading locks.
  * Files are now automatically closed when all objects within them
    are unreachable. Previously, if File.close() was not explicitly
    closed, files would remain open and "leaks" were possible if the
    File object was lost.
  * The entire API is now believed to be thread-safe (feedback
    welcome!).
  * External links now work if the target file is already
    open. Previously this was not possible because of a mismatch in
    the file close strengths.
  * The options to setup.py have changed; a new top-level "configure"
    command handles options like --hdf5=/path/to/hdf5 and
  - -mpi. Setup.py now works correctly under Python 3 when these
    options are used.
  * Cython (0.17+) is now required when building from source.
  * The minimum NumPy version is now 1.6.1.
* Thu Jul 17 2014 toddrme2178@gmail.com
- Update download url
- spec file cleanups
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 2.3.1
  - Bugfix release which fixes a build issue when using the most
    recent version of HDF5 (1.8.13), and some issues with Travis-CI.
* Thu May  8 2014 toddrme2178@gmail.com
- Update to version 2.3.0
  - Support for arbitrary vlen data
  - Improved exception messages
  - Improved setuptools support
  - Multiple low-level additions
  - Improved support for MPI features
  - Readonly files can now be opened in default mode
  - Single-step build for HDF5 on Windows
* Mon Dec 16 2013 toddrme2178@gmail.com
- Update to version 2.2.1
  + Critical bugfixes
* Tue Dec 10 2013 p.drouand@gmail.com
- Update to version 2.2.0
  + This version of h5py introduces support for MPI/Parallel HDF5,
    using the mpi4py package.  Parallel HDF5 is the "native" method
    in HDF5 for sharing files and objects across multiple processes,
    in contrast to the "threading" package or "multiprocessing".
    There is a guide to using Parallel HDF5 at the h5py web site:
    http://www.h5py.org/docs/topics/mpi.html
  + Support for Python 3.3
  + Support for 16-bit "mini" floats
  + Access to the HDF5 scale-offset filter
  + Field names are now allowed when writing to a dataset
  + Region references now preserve the shape of their selections
  + File-resident "committed" types can be linked to datasets and attributes
  + Make object mtime tracking optional
  + A new "move" method on Group objects
  + Many new options for Group.copy
  + Access to HDF5's get_vfd_handle
  + Many bug fixes
- Remove depreciated %%{py_requires}
- Remove redundant %%clen section
- Remove useless %%post/postun sections
- Package ANN.rst, lzf/LICENSE.txt, lzf/README.txt and examples to
  documentation directory
* Wed Apr 24 2013 highwaystar.ru@gmail.com
- update to version 2.1.3
  - no changelog
* Sun Nov 25 2012 toddrme2178@gmail.com
- Update to 2.1.0
  - No changelog
* Thu Apr 26 2012 highwaystar.ru@gmail.com
- python3 package added
* Sun Jan  8 2012 toddrme2178@gmail.com
- new version 2.0.1
- cleaned up spec file
- merged changes lists
* Thu Aug  4 2011 highwaystar.ru@gmail.com
- version bump to 2.0.0
* Sun May 29 2011 werner.ho@gmx.de
- fixed hdf5-devel package name change
* Thu Mar 17 2011 werner.ho@gmx.de
- new version 1.3.1
* Sun Sep 19 2010 werner.ho@gmx.de
- fixed libhdf5-dependancy
* Mon Jul  5 2010 highwaystar.ru@gmail.com
- fixed libhdf5-devel to hdf5-devel
* Mon Mar 22 2010 highwaystar.ru@gmail.com
- initial release for openSUSE
- version 1.3.0
* Mon Mar 22 2010 tomin@frame10
- initial build for openSUSE
